/****************************************************************************************************************
   Program: 110_create_ltcf_file.sas

   Purpose: This program reads in the 2021 LTC Focus facility-level data set, limiting to variables needed for
            sample frame construction or that might be useful for data checks or nonresponse analyses. It also
            constructs numeric variables for whether each facility has an Alzheimer's disease special care unit
            and whether the facility is for-profit or not.

   Input files: facility_2021.xls

   Output files: ltcf_2021.sas7bdat
****************************************************************************************************************/
options nocenter mprint obs=max;

%let infile = <input directory>\facility_2021.xls;

libname out "<output directory>";

%let outfile = out.ltcf_2021;

%let invars = accpt_id prov1680 alzunit paymcaid profit totbeds avg_dailycensus prov0475 prov2720 prov2905
              prov3225 state county anymdex_pbj cnahprd_pbj lpnhprd_pbj rnhprd_pbj dchprd_pbj rn2nrs_pbj aggalz_dem;

options validvarname=v7;

proc import datafile = "&infile."
            dbms = xls
            out = ltcf_2021(keep=&invars.)
            replace;
            sheet="Sheet1";
            getnames=yes;
            guessingrows=20000;
run;

data &outfile.(keep=ltc_:);
   set ltcf_2021(rename=(prov0475 = ltc_prov_name
                         prov2720 = ltc_prov_addr
                         prov3225 = ltc_prov_city));

   length ltc_accpt_id ltc_ccn $ 6 ltc_prov_zip $ 5
          ltc_alzunit ltc_profit ltc_prov_cnty_cd ltc_anymdex_pbj $ 3 ltc_prov_state $ 2;

   ltc_accpt_id = strip(accpt_id);
   ltc_ccn = strip(prov1680);
   ltc_alzunit = strip(alzunit);
   paymcaid = strip(paymcaid);
   ltc_profit = strip(profit);
   totbeds = strip(totbeds);
   avg_dailycensus = strip(avg_dailycensus);
   ltc_prov_zip = strip(prov2905);
   ltc_prov_state = strip(state);
   ltc_prov_cnty_cd = strip(county);
   ltc_anymdex_pbj = strip(anymdex_pbj);
   cnahprd_pbj = strip(cnahprd_pbj);
   lpnhprd_pbj = strip(lpnhprd_pbj);
   rnhprd_pbj = strip(rnhprd_pbj);
   dchprd_pbj = strip(dchprd_pbj);
   rn2nrs_pbj = strip(rn2nrs_pbj);
   aggalz_dem = strip(aggalz_dem);

   label ltc_ccn = "prov1680"
         ltc_prov_zip = "prov2905";

   ltc_paymcaid = input(paymcaid,8.);
   ltc_totbeds = input(totbeds,8.);
   if avg_dailycensus ne "LNE" then ltc_avg_dailycensus = input(avg_dailycensus,8.);
   ltc_cnahprd_pbj = input(cnahprd_pbj,8.);
   ltc_lpnhprd_pbj = input(lpnhprd_pbj,8.);
   ltc_rnhprd_pbj = input(rnhprd_pbj,8.);
   ltc_dchprd_pbj = input(dchprd_pbj,8.);
   ltc_rn2nrs_pbj = input(rn2nrs_pbj,8.);
   if aggalz_dem ne "LNE" then ltc_aggalz_dem = input(aggalz_dem,8.);

   ltc_alzunit_nmrc = (upcase(ltc_alzunit) = "YES");
   ltc_profit_nmrc = (upcase(ltc_profit) = "YES");

run;