/****************************************************************************************************************
   Program: 120_create_nhc21_file.sas

   Purpose: This program reads in all monthly Nursing Home Compare files for 2021 (this includes January through
            November 2021 and January 2022 because there is no December 2021 file), limiting to variables needed to
            compare our calculation of facilities average daily census using the MDS (in a downstream program)
            or that might be useful for other data checks. The code retains the most recent monthly record for
            each facility (we do not combine records for facilities that shared a zip code and name or a zip code and
            street address). 
 
   Input files: NH_ProviderInfo_Mmmyyyy.csv (Mmm = Jan, Feb, etc.
                                             yyyy = 2021, except for Dec which will be Jan 2022)

   Output files: nhc_2021.sas7bdat
****************************************************************************************************************/
options nocenter mprint obs=max;

%let infile_pre = <input directory>;

libname out "<output directory>";

%let outfile = out.nhc_2021;

options validvarname=v7;

%macro imp_mth;

   %do i = 1 %to 12;

      %if &i. = 12 %then %do;
         %let mon = Jan;
         %let yr = 2022;
      %end;
      %else %do;
         %let yr = 2021;
         %if &i. = 1 %then %do;
            %let mon = Jan;
         %end;
         %else %if &i. = 2 %then %do;
            %let mon = Feb;
         %end;
         %else %if &i. = 3 %then %do;
            %let mon = Mar;
         %end;
         %else %if &i. = 4 %then %do;
            %let mon = Apr;
         %end;
         %else %if &i. = 5 %then %do;
            %let mon = May;
         %end;
         %else %if &i. = 6 %then %do;
            %let mon = Jun;
         %end;
         %else %if &i. = 7 %then %do;
            %let mon = Jul;
         %end;
         %else %if &i. = 8 %then %do;
            %let mon = Aug;
         %end;
         %else %if &i. = 9 %then %do;
            %let mon = Sep;
         %end;
         %else %if &i. = 10 %then %do;
            %let mon = Oct;
         %end;
         %else %if &i. = 11 %then %do;
            %let mon = Nov;
         %end;
      %end;

      %let infile = &infile_pre.\&yr.\NH_ProviderInfo_&mon.&yr..csv;

      proc import datafile = "&infile."
                  dbms = csv
                  out = nhc_2021_&i.(keep=Var1-Var18 Var21 Var22 where=(not missing(Var1)))
                  replace;
                  getnames=no;
                  datarow=2;
                  guessingrows=20000;
      run;

      data nhc_2021_&i.(drop=Var1-Var10 Var12-Var18 Var21 Var22);
         set nhc_2021_&i.(rename=(Var11 = nhc21_nmbr_crtfd_beds));

         length nhc21_legal_bus_name $ 70 nhc21_prov_name $ 51 nhc21_prov_addr $ 50 nhc21_ownership_type $ 38 
                nhc21_prov_cnty_name nhc21_prov_type $ 21 nhc21_prov_city $ 20 nhc21_prov_phone $ 10
                nhc21_ccn $ 6 nhc21_prov_zip $ 5 nhc21_prov_cnty_cd $ 3
                nhc21_prov_state nhc21_avg_nmbr_rsdnts_per_day_fn $ 2
                nhc21_resides_in_hospital nhc21_cont_care_rtrmnt_cmnty
                nhc21_hlth_insp_gt_2yrs_ago nhc21_changed_owner_lst12mnths $ 1;

         nhc21_month = &i.;

         nhc21_ccn = strip(Var1);
         nhc21_prov_name = strip(Var2);
         nhc21_prov_addr = strip(Var3);
         nhc21_prov_city = strip(Var4);
         nhc21_prov_zip = strip(Var6);
         nhc21_prov_state = strip(Var5);
         nhc21_prov_phone = strip(Var7);
         nhc21_prov_cnty_cd = strip(Var8);
         nhc21_prov_cnty_name = strip(Var9);
         nhc21_ownership_type = strip(Var10);
         Var12 = strip(Var12);
         nhc21_avg_nmbr_rsdnts_per_day_fn = strip(Var13);
         nhc21_prov_type = strip(Var14);
         nhc21_resides_in_hospital = strip(Var15);
         nhc21_legal_bus_name = strip(Var16);
         Var17 = strip(Var17);
         nhc21_cont_care_rtrmnt_cmnty = strip(Var18);
         nhc21_hlth_insp_gt_2yrs_ago = strip(Var21);
         nhc21_changed_owner_lst12mnths = strip(Var22);

         nhc21_avg_nmbr_rsdnts_per_day = input(Var12,8.);
         nhc21_date_first_approved = mdy(input(substrn(Var17,6,2),8.),
                                         input(substrn(Var17,9,2),8.),
                                         input(substrn(Var17,1,4),8.));

         format nhc21_date_first_approved date9.;
   
      run;

      proc sort data=nhc_2021_&i.;
         by nhc21_ccn;
      run;

   %end;

%mend imp_mth;

%imp_mth;

data nhc_2021(drop=nhc21_avg_nmbr_rsdnts_per_day)
     rsdnts_per_day(keep=nhc21_ccn nhc21_avg_nmbr_rsdnts_per_day);
   set nhc_2021_1-nhc_2021_12;
   by nhc21_ccn;

   if last.nhc21_ccn then output nhc_2021;
   output rsdnts_per_day;

run;

proc means data=rsdnts_per_day noprint;
   by nhc21_ccn;
   var nhc21_avg_nmbr_rsdnts_per_day;
   output out=avg_rsdnts_per_day(drop=_type_ _freq_) mean=nhc21_mthly_avg_dly_c;
run;

data &outfile.;
   merge nhc_2021 avg_rsdnts_per_day;
   by nhc21_ccn;
run;