/****************************************************************************************************************
   Program: 130_create_nhc24_file.sas

   Purpose: This program reads in the most recent publicly available month of Nursing Home Compare,
            including all variables available in the provider information file. The code constructs a numeric 
            variable related to ownership type.

   Input files: NH_ProviderInfo_Jan2024.csv

   Output files: nhc_2024.sas7bdat
****************************************************************************************************************/
options nocenter mprint obs=max;

%let infile = <input directory>\NH_ProviderInfo_Jan2024.csv;

libname out "<output directory>";

%let outfile = out.nhc_2024;

options validvarname=v7;

proc import datafile = "&infile."
            dbms = csv
            out = nhc_2024(where=(not missing(Var1)))
            replace;
            getnames=no;
            datarow=2;
            guessingrows=20000;
run;

data nhc_2024(drop=Var1-Var10 Var12-Var64 Var72 Var80 Var88 Var91 Var96 Var99 Var100);
   set nhc_2024(rename=(Var11 = nhc24_nmbr_crtfd_beds
                        Var65 = nhc24_rc1_tot_nbr_hlth_dfcncs
                        Var66 = nhc24_rc1_nbr_std_hlth_dfcncs
                        Var67 = nhc24_rc1_nbr_cmplnt_hlth_dfcncs
                        Var68 = nhc24_rc1_hlth_dfcnc_score
                        Var69 = nhc24_rc1_nbr_hlth_revisits
                        Var70 = nhc24_rc1_hlth_revisit_score
                        Var71 = nhc24_rc1_tot_hlth_score
                        Var73 = nhc24_rc2_tot_nbr_hlth_dfcncs
                        Var74 = nhc24_rc2_nbr_std_hlth_dfcncs
                        Var75 = nhc24_rc2_nbr_cmplnt_hlth_dfcncs
                        Var76 = nhc24_rc2_hlth_dfcnc_score
                        Var77 = nhc24_rc2_nbr_hlth_revisits
                        Var78 = nhc24_rc2_hlth_revisit_score
                        Var79 = nhc24_rc2_tot_hlth_score
                        Var81 = nhc24_rc3_tot_nbr_hlth_dfcncs
                        Var82 = nhc24_rc3_nbr_std_hlth_dfcncs
                        Var83 = nhc24_rc3_nbr_cmplnt_hlth_dfcncs
                        Var84 = nhc24_rc3_hlth_dfcnc_score
                        Var85 = nhc24_rc3_nbr_hlth_revisits
                        Var86 = nhc24_rc3_hlth_revisit_score
                        Var87 = nhc24_rc3_tot_hlth_score
                        Var89 = nhc24_nbr_fclty_rptd_incidents
                        Var90 = nhc24_nbr_substntd_complaints
                        Var92 = nhc24_nmbr_of_fines
                        Var93 = nhc24_tot_amt_fines
                        Var94 = nhc24_nmbr_pmt_denials
                        Var95 = nhc24_tot_nmbr_penalties
                        Var97 = nhc24_latitude
                        Var98 = nhc24_longitude));

   length nhc24_affiliated_entity_name $ 88 nhc24_location $ 72 nhc24_legal_bus_name $ 70 nhc24_prov_name $ 52
          nhc24_prov_addr $ 50 nhc24_ownership_type $ 38 nhc24_prov_cnty_name nhc24_prov_type $ 21
          nhc24_prov_city $ 20 nhc24_automatic_sprinklers $ 18 nhc24_special_focus_status $ 13
          nhc24_prov_phone $ 10 nhc24_resident_family_council $ 8 nhc24_ccn $ 6
          nhc24_prov_zip $ 5 nhc24_prov_cnty_cd $ 3 
          nhc24_prov_state nhc24_avg_nmbr_rsdnts_per_day_fn nhc24_overall_rating_fn
          nhc24_hlth_inspection_rating_fn nhc24_qm_rating_fn nhc24_long_stay_qm_rating_fn
          nhc24_short_stay_qm_rating_fn nhc24_staffing_rating_fn nhc24_geocoding_fn $ 2
          nhc24_resides_in_hospital nhc24_cont_care_rtrmnt_cmnty nhc24_abuse_icon nhc24_hlth_insp_gt_2yrs_ago
          nhc24_changed_owner_lst12mnths nhc24_rptd_staffing_fn nhc24_phys_thrpst_staffing_fn
          nhc24_tot_nrsg_staff_turnover_fn nhc24_rgstrd_nurse_turnover_fn nhc24_num_admin_left_nh_fn $ 1;

   nhc24_ccn = strip(Var1);
   nhc24_prov_name = strip(Var2);
   nhc24_prov_addr = strip(Var3);
   nhc24_prov_city = strip(Var4);
   nhc24_prov_state = strip(Var5);
   nhc24_prov_zip = strip(Var6);
   nhc24_prov_phone = strip(Var7);
   nhc24_prov_cnty_cd = strip(Var8);
   nhc24_prov_cnty_name = strip(Var9);
   nhc24_ownership_type = strip(Var10);
   Var12 = strip(Var12);
   nhc24_avg_nmbr_rsdnts_per_day_fn = strip(Var13);
   nhc24_prov_type = strip(Var14);
   nhc24_resides_in_hospital = strip(Var15);
   nhc24_legal_bus_name = strip(Var16);
   Var17 = strip(Var17);
   nhc24_affiliated_entity_name = strip(Var18);
   Var19 = strip(Var19);
   nhc24_cont_care_rtrmnt_cmnty = strip(Var20);
   nhc24_special_focus_status = strip(Var21);
   nhc24_abuse_icon = strip(Var22);
   nhc24_hlth_insp_gt_2yrs_ago = strip(Var23);
   nhc24_changed_owner_lst12mnths = strip(Var24);
   nhc24_resident_family_council = strip(Var25);
   nhc24_automatic_sprinklers = strip(Var26);
   Var27 = strip(Var27);
   nhc24_overall_rating_fn = strip(Var28);
   Var29 = strip(Var29);
   nhc24_hlth_inspection_rating_fn = strip(Var30);
   Var31 = strip(Var31);
   nhc24_qm_rating_fn = strip(Var32);
   Var33 = strip(Var33);
   nhc24_long_stay_qm_rating_fn = strip(Var34);
   Var35 = strip(Var35);
   nhc24_short_stay_qm_rating_fn = strip(Var36);
   Var37 = strip(Var37);
   nhc24_staffing_rating_fn = strip(Var38);
   nhc24_rptd_staffing_fn = strip(Var39);
   nhc24_phys_thrpst_staffing_fn = strip(Var40);
   Var41 = strip(Var41);
   Var42 = strip(Var42);
   Var43 = strip(Var43);
   Var44 = strip(Var44);
   Var45 = strip(Var45);
   Var46 = strip(Var46);
   Var47 = strip(Var47);
   Var48 = strip(Var48);
   Var49 = strip(Var49);
   nhc24_tot_nrsg_staff_turnover_fn = strip(Var50);
   Var51 = strip(Var51);
   nhc24_rgstrd_nurse_turnover_fn = strip(Var52);
   Var53 = strip(Var53);
   nhc24_num_admin_left_nh_fn = strip(Var54);
   Var55 = strip(Var55);
   Var56 = strip(Var56);
   Var57 = strip(Var57);
   Var58 = strip(Var58);
   Var59 = strip(Var59);
   Var60 = strip(Var60);
   Var61 = strip(Var61);
   Var62 = strip(Var62);
   Var63 = strip(Var63);
   Var64 = strip(Var64);
   Var72 = strip(Var72);
   Var80 = strip(Var80);
   Var88 = strip(Var88);
   Var91 = strip(Var91);
   nhc24_location = strip(Var96);
   nhc24_geocoding_fn = strip(Var99);
   Var100 = strip(Var100);

   nhc24_avg_nmbr_rsdnts_per_day = input(Var12,8.);
   nhc24_date_first_approved = mdy(input(substrn(Var17,6,2),8.),
                                   input(substrn(Var17,9,2),8.),
                                   input(substrn(Var17,1,4),8.));
   nhc24_affiliated_entity_id = input(Var19,8.);
   nhc24_overall_rating = input(Var27,8.);
   nhc24_hlth_inspection_rating = input(Var29,8.);
   nhc24_qm_rating = input(Var31,8.);
   nhc24_long_stay_qm_rating = input(Var33,8.);
   nhc24_short_stay_qm_rating = input(Var35,8.);
   nhc24_staffing_rating = input(Var37,8.);
   nhc24_rptd_na_hrs_pppd = input(Var41,8.);
   nhc24_rptd_lpn_hrs_pppd = input(Var42,8.);
   nhc24_rptd_rn_hrs_pppd = input(Var43,8.);
   nhc24_rptd_lcnsd_hrs_pppd = input(Var44,8.);
   nhc24_rptd_tot_nrsg_hrs_pppd = input(Var45,8.);
   nhc24_wknd_tot_nrsg_hrs_pppd = input(Var46,8.);
   nhc24_wknd_rn_hrs_pppd = input(Var47,8.);
   nhc24_rptd_phys_thrpst_hrs_pppd = input(Var48,8.);
   nhc24_tot_nrsg_staff_turnover = input(Var49,8.);
   nhc24_rgstrd_nurse_turnover = input(Var51,8.);
   nhc24_num_admin_left_nh = input(Var53,8.);
   nhc24_cm_na_hrs_pppd = input(Var55,8.);
   nhc24_cm_lpn_hrs_pppd = input(Var56,8.);
   nhc24_cm_rn_hrs_pppd = input(Var57,8.);
   nhc24_cm_tot_nrsg_hrs_pppd = input(Var58,8.);
   nhc24_adj_na_hrs_pppd = input(Var59,8.);
   nhc24_adj_lpn_hrs_pppd = input(Var60,8.);
   nhc24_adj_rn_hrs_pppd = input(Var61,8.);
   nhc24_adj_tot_nrsg_hrs_pppd = input(Var62,8.);
   nhc24_adj_wknd_tot_nrsg_hrs_pppd = input(Var63,8.);
   nhc24_rc1_std_survey_hlth_date = mdy(input(substrn(Var64,6,2),8.),
                                        input(substrn(Var64,9,2),8.),
                                        input(substrn(Var64,1,4),8.));
   if not missing(Var72) then nhc24_rc2_std_survey_hlth_date = mdy(input(substrn(Var72,6,2),8.),
                                                                   input(substrn(Var72,9,2),8.),
                                                                   input(substrn(Var72,1,4),8.));
   if not missing(Var80) then nhc24_rc3_std_survey_hlth_date = mdy(input(substrn(Var80,6,2),8.),
                                                                   input(substrn(Var80,9,2),8.),
                                                                   input(substrn(Var80,1,4),8.));
   nhc24_tot_wgtd_hlth_survey_score = input(Var88,8.);
   nhc24_nbr_infctn_cntl_citations = input(Var91,8.);
   nhc24_processing_date = mdy(input(substrn(Var100,6,2),8.),
                               input(substrn(Var100,9,2),8.),
                               input(substrn(Var100,1,4),8.));

   if upcase(substrn(nhc24_ownership_type,1,10)) = "FOR PROFIT" then nhc24_owntype_sml = 1;
   else if upcase(substrn(nhc24_ownership_type,1,10)) = "NON PROFIT" then nhc24_owntype_sml = 2;
   else if upcase(substrn(nhc24_ownership_type,1,10)) = "GOVERNMENT" then nhc24_owntype_sml = 3;

   format nhc24_date_first_approved nhc24_rc1_std_survey_hlth_date nhc24_rc2_std_survey_hlth_date
          nhc24_rc3_std_survey_hlth_date nhc24_processing_date date9.;
   
run;

proc sort data=nhc_2024 out=&outfile.;
   by nhc24_ccn;
run;