/****************************************************************************************************************
   Program: 220_readin_ruca_xwalk.sas

   Purpose: This program reads in the most recent publicly available file from the U.S. Department of Agriculture
            that maps census tracts to Rural-Urban Commuting Area Codes (RUCAs) (available from:
            https://www.ers.usda.gov/data-products/rural-urban-communting-area-codes.aspx). The program reads in
            the file from Excel, renames the variables in the file, and outputs the data in a SAS data set.

   Input files: ruca2010revised.xlsx

   Output files: ruca_xwalk.sas7bdat
****************************************************************************************************************/
options nocenter mprint obs=max;

%let infile = <input directory>\ruca2010revised.xlsx;

libname out "<output directory>";

%let outfile = out.ruca_xwalk;

options validvarname=v7;

proc import datafile = "&infile."
            dbms = xlsx
            out = ruca_xwalk(rename=(A = state_county_fips_cd
                                     B = state_postal_cd
                                     C = county_name
                                     D = tract_fips_cd
                                     E = primary_ruca_cd
                                     F = secondary_ruca_cd
                                     G = population
                                     H = area_sqmi
                                     I = pop_density_per_sqmi))
            replace;
            sheet="Data";
            getnames=no;
            datarow=3;
run;

proc sort data=ruca_xwalk out=dupchk nodupkey;
   by tract_fips_cd;
run;

proc datasets library=work nolist;
  modify ruca_xwalk;
  attrib _all_ label='';
quit;

data &outfile.;
   set ruca_xwalk;
run;