/****************************************************************************************************************
   Program: 237_id_nhc24_tracts.sas

   Purpose: This program uses the most recent publicly available month of Nursing Home Compare (read in from
            the 130 program) to create geographic variables. Specifically, the code uses the provider address
            information to create a variable for state FIPS code and uses proc ginside to geocode each facility 
            to the census tract where it is located. 

   Input files: us_tract_2018_xform.sas7bdat
                nhc_2024.sas7bdat

   Output files: nhc_2024_tracts.sas7bdat
****************************************************************************************************************/
options nocenter mprint obs=max;

libname in "<input directory>" access=readonly;
libname out "<output directory>";

%let in_map = in.us_tract_2018_xform;
%let in_nhc = in.nhc_2024;
%let outfile = out.nhc_2024_tracts;

data map;
   set &in_map.;
run;

data nhc24(drop=nhc24_prov_state);
   set &in_nhc.(keep=nhc24_ccn nhc24_longitude nhc24_latitude nhc24_prov_state
                rename=(nhc24_longitude = x
                        nhc24_latitude = y));

   state_fips = stfips(nhc24_prov_state);

run;

%let setlist = ;
%macro st_loop;

%do i = 1 %to 78;
   %let process = 0;
   %if &i. = 3 or &i. = 7 or &i. = 14 or &i. = 43 or &i. = 52 %then %do;
   %end;
   %else %if &i. <= 56 %then %do;
      %let process = 1;
   %end;
   %else %if &i. = 72 %then %do;
      %let process = 1;
   %end;

   %if &process. = 1 %then %do;
      %let fips_st = %sysfunc(putn(&i.,z2.));

      data nhc24_&i.(drop=state_fips);
         set nhc24(where=(state_fips = &i.));
      run;

      data map_&i.;
         set map(where=(st_fips = "&fips_st."));
      run;

      proc ginside data=nhc24_&i. map=map_&i. out=nhc24_tracts_&i.(keep=nhc24_ccn geoid segment)
                   includeborder insideonly;
         id geoid segment;
      run;

      %let setlist = &setlist. nhc24_tracts_&i.;
   %end;
%end;

%mend st_loop;

%st_loop;

data nhc24_all_st;
   set &setlist.;
   by nhc24_ccn;
run;

data nhc24_tracts;
   merge nhc24(in=a) nhc24_all_st(in=b);
   by nhc24_ccn;
   if a;

   match = b;

run;

data &outfile.;
   set nhc24_tracts(keep=nhc24_ccn geoid match);
run;