/****************************************************************************************************************
   Program: 310_merge_ltcf_nhc21.sas

   Purpose: This program merges the LTC Focus file that was read in and processed in the 110 program to the 2021
            Nursing Home Compare file that was read in and processed in the 120 program. The code retains all
            facilities post-merge, even if they did not have a record in both input files.

   Input files: ltcf_2021.sas7bdat
                nhc_2021.sas7bdat

   Output files: ltcf_nhc21.sas7bdat
****************************************************************************************************************/
options nocenter mprint obs=max;

libname in "<input directory>" access=readonly;
libname out "<output directory>";

%let in_nhc = in.nhc_2021;
%let in_ltcf = in.ltcf_2021;
%let outfile = out.ltcf_nhc21;

data in_ltcf;
   set &in_ltcf.(rename=(ltc_ccn = ccn));

   ltc_msng_orig_ccn = missing(ccn);
   if missing(ccn) then ccn = ltc_accpt_id;

run;

proc sort data=in_ltcf;
   by ccn;
run;

data in_nhc21;
   set &in_nhc.(rename=(nhc21_ccn = ccn));
run;

data &outfile.;
   merge in_ltcf(in=a) in_nhc21(in=b);
   by ccn;

   in_ltcf = a;
   in_nhc21 = b;

run;