/****************************************************************************************************************
   Program: 320_merge_final.sas

   Purpose: This program merges the previously merged LTC Focus and 2021 Nursing Home Compare data (from the 310
            program) with the geocoded, most recent month of Nursing Home Compare data. It retains all
            facilities post-merge, even if they did not have a record in both input files, and creates an 
            indicator for which file(s) the facility was found in.

   Input files: ltcf_nhc21.sas7bdat
                nhc_2024_w_rural.sas7bdat

   Output files: all_nh_facilities.sas7bdat
****************************************************************************************************************/
options nocenter mprint obs=max;

libname in "<input directory>" access=readonly;
libname out "<output directory>";

%let in_nhc = in.nhc_2024_w_rural;
%let in_pre = in.ltcf_nhc21;
%let outfile = out.all_nh_facilities;

data in_nhc24;
   set &in_nhc.(rename=(nhc24_ccn = ccn));
run;

data &outfile.;
   merge &in_pre.(in=a) in_nhc24(in=b);
   by ccn;

   in_nhc24 = b;

   if a then do;
      if b then do;
         if in_ltcf then do;
            if in_nhc21 then fac_file = 1;
            else fac_file = 4;
         end;
         else fac_file = 2;
      end;
      else do;
         if in_ltcf then do;
            if in_nhc21 then fac_file = 3;
            else fac_file = 5;
         end;
         else fac_file = 6;
      end;
   end;
   else do;
      in_ltcf = 0;
      in_nhc21 = 0;
      fac_file = 7;
   end;
            
run;