/****************************************************************************************************************
   Program Name: 420_avg_daily_census_suppress.sas

   Description: This program formats values of MDS-derived variables created in the prior program with "<11" if 
                the value is less than 11 or with an asterisk ("*") if the value needs to be suppressed to  
                prevent analysts from having the ability to back out the value of another variable with a cell 
                size less than 11. The program masking_formats.sas is %included in the program to apply the small  
                cell size formats. The Excel file created at the end  of this program is downloaded from the VRDC  
                to prepare for combining it with the file from the 320 program with LTC Focus and Nursing Home  
                Compare data.
				
   Input files: _410_avg_daily_census{prior year}.sas7bdat

   Output files: 420_avg_daily_census_suppressed.xlsx
****************************************************************************************************************/
options validvarname=upcase mergenoby=error compress=yes;
options mprint symbolgen obs=max nocenter ls=154 ps=58 minoperator;

libname in "<input directory>" access = readonly;

%let excel_out = <output directory>;

%let indata = in._410_avg_daily_census;
%let excel_out_data = &excel_out./420_avg_daily_census_suppressed.xlsx;

%include "<format directory>/masking_formats.sas";

/* Read in  facility-level file with average daily census and related calculations, and limit
   to subset of variables; suppress values */
data avg_daily_census;
	set &indata.;
	keep ccn fac_census: fac_num_res: avg_daily: pct_dement: pct_nonwht: no_dement_days mds has_: same_fac:;
	if 0 < fac_census_all <= 10 then avg_daily_census_all = 9999999999999999;
	if 0 < fac_census_all_dement <= 10 then avg_daily_census_dmt = 9999999999999999;
	if 0 < fac_census_wht <= 10 then avg_daily_census_wht = 9999999999999999;
	if 0 < fac_census_wht_dement <= 10 then avg_daily_census_wht_dmt = 9999999999999999;
	if 0 < fac_census_nonwht <= 10 then avg_daily_census_nonwht = 9999999999999999;
	if 0 < fac_census_nonwht_dement <= 10 then avg_daily_census_nonwht_dmt = 9999999999999999;

	if fac_census_wht > 10 and 0 < fac_census_nonwht <= 10 then fac_census_wht = 9999999999999999;
	if fac_census_nonwht > 10 and 0 < fac_census_wht <= 10 then fac_census_nonwht = 9999999999999999;

	if fac_census_wht_dement > 10 and 0 < fac_census_nonwht_dement <= 10 then fac_census_wht_dement = 9999999999999999;
	if fac_census_nonwht_dement > 10 and 0 < fac_census_wht_dement <= 10 then fac_census_nonwht_dement = 9999999999999999;

	if fac_census_all > 10 and fac_census_all_dement <= 10 then pct_dement_days = 9999999999999999;
	if fac_census_all > 10 and fac_census_nonwht <= 10 then pct_nonwht_days = 9999999999999999;
	if fac_census_all_dement > 10 and fac_census_nonwht_dement <= 10 then pct_nonwht_dement_days = 9999999999999999;
	if fac_num_res > 10 and 0 < fac_num_res_dement <= 10 then pct_dement_rsdnts = 9999999999999999;
	format fac_census: mask_strict. fac_num_res: mask. avg_daily: pct_: asterisk.;
run;

/* Export to Excel, keeping formatting */
options device = actximg;
ods listing close;
title; title2; title3; title4;
ods excel file = "&excel_out_data." options(embedded_titles='no' sheet_name="SAMPLE_FRAME" sheet_interval='none');
proc print data = avg_daily_census noobs;
run;
ods excel close;
ods listing;